API reference — aeolus 0.4.9+9.g5a71939.dirty documentation

# API reference

Here the reference documentation is provided for aeolus’s public API. If you are new to the package or just trying to get a feel for the overall workflow, you are better off starting in the Examples section of the documentation.

Warning

aeolus is under active development. It is likely that some breaking changes to the codebase will occur in the future as aeolus is improved.

- Science calculations
- Core hierarchy
- Physical constants
- Cube coordinate functionality
- I/O
- Model-specific dictionaries of variable and coordinate names
- Plotting functions
- Regions
- Subset cubes using constraints
- Synthetic observations